@@ -222,3 +222,10 @@ class API(object):
             response = resource.create(data, **kwargs)
             return HttpResponse(
                 response, content_type="application/vnd.api+json", status=201)
+        elif request.method == "DELETE":
+            if ids is None:
+                return HttpResponse("Resource ids not specified", status=404)
+
+            response = resource.delete(data, **kwargs)
+            return HttpResponse(
+                response, content_type="application/vnd.api+json", status=204)
